Learn R Programming

MLDS (version 0.0.6)

Rbind: Concatenate Objects of Class 'mlds.df' by Row

Description

Concatenate the data.frame of mlds.df objects by row and concatenate the invord attributes, also.

Usage

Rbind(...)

Arguments

...
Objects of class mlds.df.

Value

  • An object of class mlds.df that is composed of data from several experiments.

Details

Uses rbind.data.frame to concatenate the data.frame component of several mlds.df objects and then concatenates there invord attributes, as well. It would have been better to have an rbind method but since the objects inherit from class data.frame, this method would be called automatically and the invord attribute would not be updated.

Examples

Run this code
data(kk1)
data(kk2)
data(kk3)
kk <- Rbind(kk1, kk2, kk3)
nrow(kk1)
nrow(kk)
length(attr(kk1, "invord"))
length(attr(kk, "invord"))

Run the code above in your browser using DataLab