lik6pt(x, Six.Pts, ...)mldsA, B, E. Each data.frame corresponds to a sample from a difference scaling experiment. The corresponding rows of the three data.frames yield the triples of trials that provide a 6Get6pts, mlds,
simu.6ptdata(kk1)
x.df <- mlds(SwapOrder(kk1))
lik6pt(x.df, Get6pts(x.df))Run the code above in your browser using DataLab