Rbind: Concatenate Objects of Class 'mlds.df' by Row
Description
Concatenate the data.frame of mlds.df objects by row
and concatenate the invord attributes, also.
Usage
Rbind(...)
Arguments
...
Objects of class mlds.df.
Value
An object of class mlds.df that is composed of data from several experiments.
Details
Uses rbind.data.frame to concatenate the data.frame component of several mlds.df objects and then concatenates there invord attributes, as well. It would have been better to have an rbind method but since the objects inherit from class data.frame, this method would be called automatically and the invord attribute would not be updated.